==> ohigan_game_0.2.1.tar.bz2: ohigan_game_0.2.1/ohigan_game.py <==
import pygame 
from pygame.locals import *
from sys import exit
import random
import datetime
import time
import math
import pickle
#import player

chara="ojizousan2.png" 
bota_image2="bota2.png"
background_image= 'j.jpg'
background_image_filename= 'j.jpg'
title_filename="title.png"
end_image="gameover.png"
isi_dead = False
HOLIZON = 250
def distance(x1,y1,x2,y2):
        math.sqrt((x1-x2)**2 + (y1-y2)**2)

score = 0
score1 = 0   
clock=pygame.time.Clock()
speed=50
global dead
dead = False
global dd
dd = 0

cc = 0
class Score():
    try:
        def load(self):
            f = open("score.txt","r2")
            xy = pickle.load(f)
            return xy
    except IOError:
        d = open("score.txt","w")
        kk = 0
        pickle.dump(kk,d)

    def save(self,kk):
        d = open("score.txt","w")
        pickle.dump(kk,d)

class Input:
    left = K_LEFT
def load_image(fname):
    image = pygame.image.load(fname).convert()


class TitleScene:
    def __init__(self):
        print("")
        global title_image

        title_image = pygame.image.load(title_filename).convert()
    def start():
        print("")
        #print("d")
    def act(self):
        print("")

        #if input.left == True:
        #    return game
        #else:
        #return none
        #print("")
    def render(self,screen):
        
        screen.blit(title_image,(0,0))


class GameScene:
    def __init__(self):
        #items = Items()
        global ddd
        self.ddd = 0
        global xxx
        xxx = 1
        global bg_image
        bg_image = pygame.image.load(background_image).convert()
        #items = Iems()
        
    def act(self):
        time_passed=clock.tick()
        time_passed_seconds = time_passed / 1000.0
        distance_moved = time_passed_seconds * speed
        bota1.act(distance_moved)
        bota1.atari(player.x,player.y)
        bota2.act(distance_moved)
        bota2.atari(player.x,player.y)
        bota3.act(distance_moved)
        bota3.atari(player.x,player.y)
        isi1.act(distance_moved)
        isi1.atari(player.x,player.y)
        isi2.act(distance_moved)
        isi2.atari(player.x,player.y)
        isi3.act(distance_moved)
        isi3.atari(player.x,player.y)
        player.y+=move_y
        player.x+=move_x
        pygame.time.set_timer(USEREVENT+1,1000)
        global cc
        cc = cc + 1
        #global move_x
        #global move_y
        #xxx = xxx + 0.3
        #print("2")

    def render(self,screen):
        screen.blit(bg_image,(0,0))
        bota1.render(screen)
        bota2.render(screen)
        bota3.render(screen)
        isi1.render(screen)
        isi2.render(screen)
        isi3.render(screen)
        player.render(screen)
        dd = (cc / 100)
        if dd > 60:
            time.sleep(3)
            scene[0].act()
            scene[0].render(screen)
            scene[2].act()
            scene[2].render(screen)

        font = pygame.font.Font(None,33)
        scoretext = font.render("TIME"+str(dd),False,(33,33,0))
        screen.blit(scoretext,(1,30))
        font = pygame.font.Font(None,33)
        scoretext = font.render("SCORE"+str(score),False,(33,33,0))
        screen.blit(scoretext,(1,1))
        global x


        """
        font = pygame.font.Font(None,33)
        scoretext = font.render("SCORE"+str("jj"),False,(33,33,0))
        screen.blit(scoretext,(1,1))
        """
class EndScene:
    def __init__(self):
        #items = Items()
        global bgg_image
        bgg_image = pygame.image.load(end_image).convert()
        #items = Iems()
    def act(self):
        #scene[0].act()
        #scene[0].render(screen)

        global move_x
        global move_y
        #xxx = xxx + 0.3
        #print("2")
    def render(self,screen):
        screen.blit(bgg_image,(0,0))
        """
        font = pygame.font.Font(None,33)
        scoretext = font.render("SCORE"+str(score),False,(33,33,0))
        screen.blit(scoretext,(1,1))
        """
        print("ss")


class EndSceneScore:
    def __init__(self):
        #items = Items()
        global bgg_image
        bgg_image = pygame.image.load(end_image).convert()
        #items = Iems()
    def act(self):
        global move_x
        global move_y
        #xxx = xxx + 0.3
        #print("2")
    def render(self,screen):
        screen.blit(bgg_image,(0,0))
        """
        font = pygame.font.Font(None,33)
        scoretext = font.render("SCORE"+str(score),False,(33,33,0))
        screen.blit(scoretext,(1,1))
        """
        print("ss")


class Player():
    def  __init__(self,x,y):
        image = load_image("ojizousan2.png")
        self.x = x
        self.y = y
        self.width= 0
        global chara_image
        chara_image = pygame.image.load(chara).convert_alpha()
        return image
        ##yy = HOLIZON - image.get_height
    def center():
        #print("player")
        cx = self.x + (image.w / 2)
        cy = self.y + (image.h / 2)
    def act(xx):

        print("")
    def render(self,screen):
        screen.blit(chara_image,(player.x,player.y))

class Item():
    def __init__(self,x,y,v):
        self.x,self.y,self.v=x,y,v
class Items():
    def __init__(self,xxxx,yyyy,vvvv):
        self.xxxx = (xxxx + random.random()*640)
        self.yyyy = (yyyy + random.random()*480)
        self.vvvv = vvvv
        self.height = 0
        self.width = 0
        self.font = 0
    def act(self):
        self.yyyy = self.yyyy + 0.2
        if int(self.yyyy) == 480:
            self.yyyy = 0
            self.xxxx = random.random() * 640
            """
            font = pygame.font.Font(None,33)
            scoretext = font.render("SCORE SCORE"+str(score),False,(33,33,0))
            screen.blit(scoretext,(200,110))
            """
        #if px < int(self.xxxx) + 50 and py < (py + 50) and px > (int(self.xxxx)) and py > (int(self.yyyy)):
        #    print("")

    def render(self,screen):
        screen.blit(image,(int(self.xxxx),int(self.yyyy)))

pygame.init()
screen = pygame.display.set_mode((640,480),0,32)

pygame.joystick.init()
try:
    joy = pygame.joystick.Joystick(0)
    joy.init()
except:
    print("w")
global getsss
getsss = []
game = GameScene()
scoreob = Score()
global atari1
endscenescore=EndSceneScore()
atari1 = False
class Bota(Items):
    global  bota_image2
    global  bota_image
    global  image

    def act(self,distance_moved):
        self.yyyy = self.yyyy + distance_moved
        if int(self.yyyy) == 480:
            self.yyyy = 0
            self.xxxx = random.random() * 640
    bota_image = pygame.image.load(bota_image2).convert_alpha()
    def atari(self,px,py):
        #X0 < X3 and X2 < X1 and Y0 < Y3 and Y2 < Y1)
        SphA = 20
        SphB = 30
        dx = (px + 29) - (self.xxxx + 29)
        dy = (py + 29) - (self.yyyy + 29)
        if (dx*dx+dy*dy < (SphA+SphB)*(SphA+SphB)):
        #if px py px1 py1
        #if  distance(self.xxxx + 20,self.yyyy+20,px + 8,py + 8) < 55:
        #if px < int(self.xxxx) and py < (self.yyyy) and  self.yyyy + 30 and self.xxxx + 30:
        #if px < (int(self.xxxx) + 55) and py < (int(self.yyyy) + 55) and px > (int(self.xxxx)) and py > (int(self.yyyy)):
        #if px < (int(self.xxxx) + 50) and py < (self.yyyy + 20) and self.xxxx <( px +30):
        #if px < (px + 50) and py < (py + 50) and px < ((int(self.xxxx)) + 50):
            #self.xxxx = random.random()*640 
            self.xxxx = random.random()*640 
            self.yyyy = 0
            global score
            score = score + 1

    def render(self,screen):
        """
        font = pygame.font.Font(None,33)
        scoretext = font.render("SCORE"+str(score),False,(33,33,0))
        screen.blit(scoretext,(1,10))
"""
        print(int(self.yyyy))
        print(player.x)
        print(player.y)
        screen.blit(bota_image,(int(self.xxxx),int(self.yyyy)))
class Block(Items):
    isi_dead = False
    global isi
    global image
    #isi = load_image("isi.png")
    isi = pygame.image.load("isi.png").convert_alpha()
    image = isi
    def act(self,distance_moved):
        self.yyyy = self.yyyy + distance_moved
        print(str(self.yyyy))
        
        if int(self.yyyy) == 480:
            self.yyyy = 0
            self.xxxx = random.random() * 640
    bota_image = pygame.image.load(bota_image2).convert_alpha()
    def atari(self,px,py):
        SphA = 10
        SphB = 20
        dx = (px + 69) - (self.xxxx + 59)
        dy = (py + 69) - (self.yyyy + 59)
        if (dx*dx+dy*dy < (SphA+SphB)*(SphA+SphB)):
            self.xxxx = random.random()*640 
            self.yyyy = 0
            global dead
            dead = True
            exit()
    def render(self,screen):
        #pygame.draw.rect(screen,(244,44,41),(self.xxxx,self.yyyy,50,50))
        """
        font = pygame.font.Font(None,33)
        scoretext = font.render("SCORE"+str(dead),False,(33,33,0))
        screen.blit(scoretext,(1,40))
        """
        screen.blit(isi,(int(self.xxxx),int(self.yyyy)))
        
title = TitleScene()
game = GameScene()
end = EndScene()
Scenes = [title,game,end] 
bota1 = Bota(3,4,3)
bota2 = Bota(3,4,3)
bota3= Bota(3,4,3)
isi1 = Block(3,4,5)
isi2 = Block(3,4,5)
isi3 = Block(3,4,5)
player = Player(0,380)
item1 = Items(random.random()*640,random.random()*480,5)
item2 = Items(222,34,3)
item3 = Items(22,34,3)
item4 = Items(2,34,3)
item5 = Items(12,34,3)
item6 = Items(12,34,3)
item7 = Items(12,34,3)
yyy = 0

y1=10
move_x=0
move_y=0
#j = TitleScene()
scene = [title,game,end]
while True:
    for event in pygame.event.get():
        if event.type == QUIT:
            exit()
    if event.type == KEYDOWN:
       if event.key == K_ESCAPE:
            exit()
       if event.key == K_LEFT:
           move_x = -1
       if event.key == K_RIGHT:
            move_x = +1
       if event.key == K_UP:
           move_y = -1
       if event.key == K_DOWN:
            move_y = +1
    if event.type == KEYUP:
       if event.key == K_LEFT:
          move_x = 0
       if event.key == K_RIGHT:
          move_x = 0
       if event.key == K_UP:
           move_y = 0
       if event.key == K_DOWN:
           move_y = 0
    if event.type == pygame.locals.JOYHATMOTION:
        getsss = joy.get_hat(0)
        print(getsss)
        print("hat")
        R = (1,0)
        L = (-1,0)
        U = (0,1)
        D = (0,-1)
        RU = (1,1)
        LU = (-1,1)
        RD = (1,-1)
        LD = (-1,-1)
        DEF=(0,0)
        if getsss == DEF:
            move_x = 0
            move_y = 0
        if getsss == R:
            move_x = +1
        if getsss == L:
            move_x = -1
        if getsss == U:
            move_y = -1
        if getsss == D:
            move_y = +1
        if getsss == LU:
            move_y = -1
            move_x = -1
        if getsss == RU:
            move_y = -1
            move_x = +1
        if getsss == LD:
            move_y = +1
            move_x = -1
        if getsss == RD:
            move_y = 1
            move_x = 1
            
            """
        next_scene = scene.act()
        if next_scene:
            scene = Scenes[next_scene]
            """

    game.act()
    game.render(screen)
    scoreob.save(score)
    ss = (bg_image.get_rect())
    print(ss[3])
    pygame.display.update()
"""
    if dead == False:
        scene[1].act()
        scene[1].render(screen)
    elif dead == True:
        scene[2].render(screen)
        scene[2].act()
"""



    #print(j[1])

==> ohigan_game_0.2.3.tar.bz2: ohigan_game_0.2.3/ohigan_game.py <==
import pygame 
from pygame.locals import *
from sys import exit
import random
import datetime
import time
import math
import pickle
#import player

chara="ojizousan2.png" 
bota_image2="bota2.png"
background_image= 'j.jpg'
background_image_filename= 'j.jpg'
title_filename="title.png"
end_image="gameover.png"
isi_dead = False
titleflag=1
HOLIZON = 250
def distance(x1,y1,x2,y2):
        math.sqrt((x1-x2)**2 + (y1-y2)**2)
global score
global score3
score = 0
score3 = 0
score1 = 0   
clock=pygame.time.Clock()
speed=50
pygame.init()
global dead
dead = False
global dd
dd = 0

cc = 0

class Input:
    left = K_LEFT
def load_image(fname):
    image = pygame.image.load(fname).convert()


class TitleScene:
    def __init__(self):
        print("")
        global title_image

        title_image = pygame.image.load(title_filename).convert()
    def start():
        print("")
        #print("d")
    def act(self):
        print("")

        #if input.left == True:
        #    return game
        #else:
        #return none
        #print("")
    def render(self,screen):
        
        screen.blit(title_image,(0,0))


class GameScene:
    def __init__(self):
        #items = Items()
        global ddd
        self.ddd = 0
        global xxx
        xxx = 1
        global bg_image
        bg_image = pygame.image.load(background_image).convert()
        #items = Iems()
        
    def act(self):
        time_passed=clock.tick()
        time_passed_seconds = time_passed / 1000.0
        distance_moved = time_passed_seconds * speed
        bota1.act(distance_moved)
        bota1.atari(player.x,player.y)
        bota2.act(distance_moved)
        bota2.atari(player.x,player.y)
        bota3.act(distance_moved)
        bota3.atari(player.x,player.y)
        isi1.act(distance_moved)
        isi1.atari(player.x,player.y)
        isi2.act(distance_moved)
        isi2.atari(player.x,player.y)
        isi3.act(distance_moved)
        isi3.atari(player.x,player.y)
        player.y+=move_y
        player.x+=move_x
        pygame.time.set_timer(USEREVENT+1,1000)
        global cc
        cc = cc + 1
        #global move_x
        #global move_y
        #xxx = xxx + 0.3
        #print("2")

    def render(self,screen):
        screen.blit(bg_image,(0,0))
        bota1.render(screen)
        bota2.render(screen)
        bota3.render(screen)
        isi1.render(screen)
        isi2.render(screen)
        isi3.render(screen)
        player.render(screen)
        dd = (cc / 100)
        if dd > 60:
            time.sleep(3)
            if score < score3:
                scoreob.save(score)
            else:
                print()
            scene[0].act()
            scene[0].render(screen)
            scene[2].act()
            scene[2].render(screen)
            pygame.display.update()
            time.sleep(3)
            exit()

        font = pygame.font.Font(None,33)
        scoretext = font.render("TIME"+str(dd),False,(33,33,0))
        screen.blit(scoretext,(1,30))
        font = pygame.font.Font(None,33)
        scoretext = font.render("SCORE"+str(score),False,(33,33,0))
        screen.blit(scoretext,(1,1))
        font = pygame.font.Font(None,33)
        scoretext = font.render("Best SCORE"+str(score3),False,(33,33,0))
        screen.blit(scoretext,(1,55))
        pygame.display.update()
        global x


        """
        font = pygame.font.Font(None,33)
        scoretext = font.render("SCORE"+str("jj"),False,(33,33,0))
        screen.blit(scoretext,(1,1))
        """
class EndScene:
    def __init__(self):
        #items = Items()
        global bgg_image
        bgg_image = pygame.image.load(end_image).convert()
        #items = Iems()
    def act(self):
        #scene[0].act()
        #scene[0].render(screen)

        global move_x
        global move_y
        #xxx = xxx + 0.3
        #print("2")
    def render(self,screen):
        screen.blit(bgg_image,(0,0))
        font = pygame.font.Font(None,33)
        scoretext = font.render("BEST SCORE"+str(score),False,(33,33,0))
        screen.blit(scoretext,(1,100))
        print("ss")


class EndSceneScore:
    def __init__(self):
        #items = Items()
        global bgg_image
        bgg_image = pygame.image.load(end_image).convert()
        #items = Iems()
    def act(self):
        global move_x
        global move_y
        #xxx = xxx + 0.3
        #print("2")
    def render(self,screen):
        screen.blit(bgg_image,(0,0))
        """
        font = pygame.font.Font(None,33)
        scoretext = font.render("SCORE"+str(score),False,(33,33,0))
        screen.blit(scoretext,(1,1))
        """
        print("ss")


class Player():
    def  __init__(self,x,y):
        image = load_image("ojizousan2.png")
        self.x = x
        self.y = y
        self.width= 0
        global chara_image
        chara_image = pygame.image.load(chara).convert_alpha()
        return image
        ##yy = HOLIZON - image.get_height
    def center():
        #print("player")
        cx = self.x + (image.w / 2)
        cy = self.y + (image.h / 2)
    def act(xx):

        print("")
    def render(self,screen):
        screen.blit(chara_image,(player.x,player.y))

class Item():
    def __init__(self,x,y,v):
        self.x,self.y,self.v=x,y,v
class Items():
    def __init__(self,xxxx,yyyy,vvvv):
        self.xxxx = (xxxx + random.random()*640)
        self.yyyy = (yyyy + random.random()*480)
        self.vvvv = vvvv
        self.height = 0
        self.width = 0
        self.font = 0
    def act(self):
        self.yyyy = self.yyyy + 0.2
        if int(self.yyyy) == 480:
            self.yyyy = 0
            self.xxxx = random.random() * 640
            """
            font = pygame.font.Font(None,33)
            scoretext = font.render("SCORE SCORE"+str(score),False,(33,33,0))
            screen.blit(scoretext,(200,110))
            """
        #if px < int(self.xxxx) + 50 and py < (py + 50) and px > (int(self.xxxx)) and py > (int(self.yyyy)):
        #    print("")

    def render(self,screen):
        screen.blit(image,(int(self.xxxx),int(self.yyyy)))

class Scoresaveload():
    def load(self):
        try:
            f = open("score.txt","r2")
            xy = pickle.load(f)
            return xy
        except IOError:
            d = open("score.txt","w")
            kk = 0
            pickle.dump(kk,d)

    def save(self,kk):
            d = open("score.txt","w")
            pickle.dump(kk,d)
    def act():
        if score < score3:
            font = pygame.font.Font(None,33)
            scoretext = font.render("SCORE"+str(score3),False,(33,33,0))
            screen.blit(scoretext,(1,60))
scoreob = Scoresaveload()
pygame.init()
screen = pygame.display.set_mode((640,480),0,32)

pygame.joystick.init()
try:
        joy = pygame.joystick.Joystick(0)
        joy.init()
except:
        print("w")

global getsss
score3 = scoreob.load()
class BestScore():
    def act():
        score3 = scoreob.load()
        if score < score3:
            score3 = scoreob.load
        else:
            print()
bestscore = BestScore()
        
getsss = []
game = GameScene()
global atari1
endscenescore=EndSceneScore()
atari1 = False
class Bota(Items):
    global  bota_image2
    global  bota_image
    global  image

    def act(self,distance_moved):
        self.yyyy = self.yyyy + distance_moved
        if int(self.yyyy) == 480:
            self.yyyy = 0
            self.xxxx = random.random() * 640
    bota_image = pygame.image.load(bota_image2).convert_alpha()
    def atari(self,px,py):
        #X0 < X3 and X2 < X1 and Y0 < Y3 and Y2 < Y1)
        SphA = 20
        SphB = 30
        dx = (px + 29) - (self.xxxx + 29)
        dy = (py + 29) - (self.yyyy + 29)
        if (dx*dx+dy*dy < (SphA+SphB)*(SphA+SphB)):
        #if px py px1 py1
        #if  distance(self.xxxx + 20,self.yyyy+20,px + 8,py + 8) < 55:
        #if px < int(self.xxxx) and py < (self.yyyy) and  self.yyyy + 30 and self.xxxx + 30:
        #if px < (int(self.xxxx) + 55) and py < (int(self.yyyy) + 55) and px > (int(self.xxxx)) and py > (int(self.yyyy)):
        #if px < (int(self.xxxx) + 50) and py < (self.yyyy + 20) and self.xxxx <( px +30):
        #if px < (px + 50) and py < (py + 50) and px < ((int(self.xxxx)) + 50):
            #self.xxxx = random.random()*640 
            self.xxxx = random.random()*640 
            self.yyyy = 0
            global score
            score = score + 1

    def render(self,screen):
        """
        font = pygame.font.Font(None,33)
        scoretext = font.render("SCORE"+str(score),False,(33,33,0))
        screen.blit(scoretext,(1,10))
"""
        print(int(self.yyyy))
        print(player.x)
        print(player.y)
        screen.blit(bota_image,(int(self.xxxx),int(self.yyyy)))
class Block(Items):
    isi_dead = False
    global isi
    global image
    #isi = load_image("isi.png")
    isi = pygame.image.load("isi.png").convert_alpha()
    image = isi
    def act(self,distance_moved):
        self.yyyy = self.yyyy + distance_moved
        print(str(self.yyyy))
        
        if int(self.yyyy) == 480:
            self.yyyy = 0
            self.xxxx = random.random() * 640
    bota_image = pygame.image.load(bota_image2).convert_alpha()
    def atari(self,px,py):
        SphA = 10
        SphB = 20
        dx = (px + 69) - (self.xxxx + 59)
        dy = (py + 69) - (self.yyyy + 59)
        if (dx*dx+dy*dy < (SphA+SphB)*(SphA+SphB)):
            self.xxxx = random.random()*640 
            self.yyyy = 0
            global dead
            dead = True
            exit()
    def render(self,screen):
        #pygame.draw.rect(screen,(244,44,41),(self.xxxx,self.yyyy,50,50))
        """
        font = pygame.font.Font(None,33)
        scoretext = font.render("SCORE"+str(dead),False,(33,33,0))
        screen.blit(scoretext,(1,40))
        """
        screen.blit(isi,(int(self.xxxx),int(self.yyyy)))
        
title = TitleScene()
game = GameScene()
end = EndScene()
Scenes = [title,game,end] 
bota1 = Bota(3,4,3)
bota2 = Bota(3,4,3)
bota3= Bota(3,4,3)
isi1 = Block(3,4,5)
isi2 = Block(3,4,5)
isi3 = Block(3,4,5)
player = Player(0,380)
item1 = Items(random.random()*640,random.random()*480,5)
item2 = Items(222,34,3)
item3 = Items(22,34,3)
item4 = Items(2,34,3)
item5 = Items(12,34,3)
item6 = Items(12,34,3)
item7 = Items(12,34,3)
yyy = 0

y1=10
move_x=0
move_y=0
#j = TitleScene()
scene = [title,game,end]
while True:
    for event in pygame.event.get():
        if event.type == QUIT:
            exit()
    if event.type == KEYDOWN:
       if event.key == K_ESCAPE:
            exit()
       if event.key == K_LEFT:
           move_x = -1
       if event.key == K_RIGHT:
            move_x = +1
       if event.key == K_UP:
           move_y = -1
       if event.key == K_DOWN:
            move_y = +1
    if event.type == KEYUP:
       if event.key == K_LEFT:
          move_x = 0
       if event.key == K_RIGHT:
          move_x = 0
       if event.key == K_UP:
           move_y = 0
       if event.key == K_DOWN:
           move_y = 0
    if event.type == pygame.locals.JOYHATMOTION:
        getsss = joy.get_hat(0)
        print(getsss)
        print("hat")
        R = (1,0)
        L = (-1,0)
        U = (0,1)
        D = (0,-1)
        RU = (1,1)
        LU = (-1,1)
        RD = (1,-1)
        LD = (-1,-1)
        DEF=(0,0)
        if getsss == DEF:
            move_x = 0
            move_y = 0
        if getsss == R:
            move_x = +1
        if getsss == L:
            move_x = -1
        if getsss == U:
            move_y = -1
        if getsss == D:
            move_y = +1
        if getsss == LU:
            move_y = -1
            move_x = -1
        if getsss == RU:
            move_y = -1
            move_x = +1
        if getsss == LD:
            move_y = +1
            move_x = -1
        if getsss == RD:
            move_y = 1
            move_x = 1
            
            """
        next_scene = scene.act()
        if next_scene:
            scene = Scenes[next_scene]
            """

    if titleflag == 1:
        title.act()
        title.render(screen)
        pygame.display.update()
        time.sleep(3)
        titleflag = 0
    game.act()
    game.render(screen)
    scoreob.save(score)
    ss = (bg_image.get_rect())
    print(ss[3])
"""
    if dead == False:
        scene[1].act()
        scene[1].render(screen)
    elif dead == True:
        scene[2].render(screen)
        scene[2].act()
"""



    #print(j[1])
